@@ -7,19 +7,22 @@
 ## The number below indicates the size of @input_data which can be submitted
 ## and displayed in 1 second. Output was directed to /dev/null during testing.
 ##
-## Parallel::Loops..:       600  Forking each @input is expensive
-## MCE foreach......:    18,000  Sends result after each @input
-## MCE forchunk.....:   385,000  Chunking reduces overhead even more so
+## Parallel::Loops is based on Parallel::ForkManager.
 ##
-## usage: foreach.pl [size]
+## Parallel::Loops..:       600  Forking each @input is expensive
+## MCE foreach......:    34,000  Sends result after each @input
+## MCE forseq.......:    70,000  Loops through sequence of numbers
+## MCE forchunk.....:   465,000  Chunking reduces overhead
+##
+## usage: foreach.pl [ size ]
 ##
 ###############################################################################
 
 use strict;
 use warnings;
 
-use FindBin;
-use lib "$FindBin::Bin/../lib";
+use Cwd qw(abs_path);
+use lib abs_path . "/../lib";
 
 my $prog_name = $0; $prog_name =~ s{^.*[\\/]}{}g;
 
@@ -28,6 +31,11 @@ use MCE;
 
 my $size = shift || 3000;
 
+unless ($size =~ /\A\d+\z/) {
+   print STDERR "usage: $prog_name [ size ]\n";
+   exit;
+}
+
 ###############################################################################
 ## ----------------------------------------------------------------------------
 ## Parallelize via MCE's foreach method.
@@ -44,24 +52,25 @@ my $order_id    = 1;
 
 sub display_result {
 
-   my ($wk_result, $chunk_id) = @_;
-   $result{$chunk_id} = $wk_result;
+   $result{$_[1]} = $_[0];
 
    while (1) {
       last unless exists $result{$order_id};
 
-      printf "i: %d sqrt(i): %f\n",
+      printf "n: %d sqrt(n): %f\n",
          $input_data[$order_id - 1], $result{$order_id};
 
-      delete $result{$order_id};
-      $order_id++;
+      delete $result{$order_id++};
    }
+
+   return;
 }
 
 ## Compute via MCE.
 
 my $mce = MCE->new(
-   max_workers => $max_workers
+   max_workers => $max_workers,
+   gather => \&display_result
 );
 
 $start = time();
@@ -71,8 +80,8 @@ $start = time();
 
 $mce->foreach(\@input_data, sub {
    my ($self, $chunk_ref, $chunk_id) = @_;
-   my $wk_result = sqrt($chunk_ref->[0]);
-   $self->do('display_result', $wk_result, $chunk_id);
+   my $result = sqrt($chunk_ref->[0]);
+   MCE->gather($result, $chunk_id);
 });
 
 $end = time();
