@@ -1,7 +1,17 @@
+###############################################################################
+## ----------------------------------------------------------------------------
+## MCE::Core::Input::Handle - File_path and Scalar_ref input reader.
+##
+## This package provides the read handle method used internally by the worker
+## process. Distribution follows a bank-queuing model.
+##
+## There is no public API.
+##
+###############################################################################
 
 package MCE::Core::Input::Handle;
 
-our $VERSION = '1.499_001'; $VERSION = eval $VERSION;
+our $VERSION = '1.499_002'; $VERSION = eval $VERSION;
 
 ## Items below are folded into MCE.
 
@@ -155,24 +165,3 @@ sub _worker_read_handle {
 
 1;
 
-__END__
-
-=head1 NAME
-
-MCE::Core::Input::Handle - File_Path/Scalar_Ref input reader for MCE.
-
-=head1 SYNOPSIS
-
-There is no public API.
-
-=head1 DESCRIPTION
-
-This package provides the read handle method used internally by the worker
-process. Distribution follows a bank-queuing model.
-
-=head1 SEE ALSO
-
-L<MCE>
-
-=cut
-
