@@ -1,28 +1,6 @@
 ###############################################################################
 ## ----------------------------------------------------------------------------
-## MCE::Queue
-## -- Provides queues for Many-Core Engine.
-##
-## ## MCE::Queue can be utilized in the following 3 modes:
-##
-##    A) use MCE;           B) use MCE::Queue;    C) use MCE::Queue;
-##       use MCE::Queue;       use MCE;
-##
-## A) Loading MCE prior to inclusion of MCE::Queue:
-##    The dequeue method blocks for the manager process and workers.
-##    The manager process contains the data. Workers send/request data.
-##
-##    Creating a queue from inside the worker will run the queue in
-##    standalone mode. Think workers being able to have local queues.
-##
-## B) Loading MCE::Queue prior to inclusion of MCE:
-##    Queues behave as if running in standalone mode for both the manager
-##    and worker processes for the duration of the script.
-##
-## C) Standalone mode without the inclusion of MCE:
-##    The dequeue method is non-blocking in this mode. This mode is
-##    speedy due to minimum overhead (no socket or locking involved).
-##    Basically, the MCE module is not required to use MCE::Queue.
+## MCE::Queue - Hybrid queues (normal including priority) for Many-core Engine.
 ##
 ###############################################################################
 
@@ -35,26 +13,12 @@ use Fcntl qw( :flock O_RDONLY );
 use Socket qw( :crlf AF_UNIX SOCK_STREAM PF_UNSPEC );
 use Scalar::Util qw( looks_like_number );
 
-our $VERSION = '1.499_001'; $VERSION = eval $VERSION;
+our $VERSION = '1.499_002'; $VERSION = eval $VERSION;
 
 ###############################################################################
 ## ----------------------------------------------------------------------------
 ## Import routine.
 ##
-## ** Module options for priority queuing: (no effect to normal queuing)
-##
-##    porder => $HIGHEST = Highest priority items are dequeued first
-##              $LOWEST  = Lowest priority items are dequeued first
-##
-##    type   => $FIFO    = First in, first out
-##              $LILO    =    (Synonym for FIFO)
-##              $LIFO    = Last in, first out
-##              $FILO    =    (Synonym for LIFO)
-##
-## use MCE::Queue porder => $MCE::Queue::HIGHEST, type => $MCE::Queue::FIFO;
-##
-## use MCE::Queue;      same as above 
-##
 ###############################################################################
 
 our ($HIGHEST, $LOWEST, $FIFO, $LILO, $LIFO, $FILO) = (1, 0, 1, 1, 0, 0);
@@ -97,6 +61,7 @@ sub import {
       _mce_m_init();
    }
    else {
+      *{ 'MCE::Queue::clear'      } = \&MCE::Queue::_clear;
       *{ 'MCE::Queue::enqueue'    } = \&MCE::Queue::_enqueue;
       *{ 'MCE::Queue::enqueuep'   } = \&MCE::Queue::_enqueuep;
       *{ 'MCE::Queue::dequeue'    } = \&MCE::Queue::_dequeue;
@@ -121,6 +86,8 @@ sub import {
 
 use constant {
 
+   OUTPUT_C_QUE => 'C~QUE',           ## Clear the queue
+
    OUTPUT_A_QUE => 'A~QUE',           ## Enqueue into queue (array)
    OUTPUT_A_QUP => 'A~QUP',           ## Enqueue into queue (array (p))
    OUTPUT_R_QUE => 'R~QUE',           ## Enqueue into queue (reference)
@@ -257,18 +224,19 @@ sub new {
 
 ###############################################################################
 ## ----------------------------------------------------------------------------
-## Accessor methods.
+## Clear method.
 ##
 ###############################################################################
 
-sub porder {
+sub _clear {
 
-   return shift->{_porder};
-}
+   my $_queue = shift;
 
-sub type {
+   %{ $_queue->{_datp} } = ();
+   @{ $_queue->{_datq} } = ();
+   @{ $_queue->{_heap} } = ();
 
-   return shift->{_type};
+   return;
 }
 
 ###############################################################################
@@ -595,6 +563,24 @@ sub _heap_insert_high {
 
    my %_output_function = (
 
+      OUTPUT_C_QUE.$LF => sub {                   ## Clear the queue
+
+         $_DAU_R_SOCK = $$_DAU_R_SOCK_REF;
+         my $_buffer;
+
+         chomp($_id = <$_DAU_R_SOCK>);
+         $_queue = $_queues->{$_id};
+
+         sysread $_queue->{_qr_sock}, $_buffer, 1
+            if ($_queue->_has_data());
+
+         $_queue->_clear();
+
+         print $_DAU_R_SOCK $LF;
+
+         return;
+      },
+
       ## ----------------------------------------------------------------------
 
       OUTPUT_A_QUE.$LF => sub {                   ## Enqueue into queue (A)
@@ -1006,6 +992,7 @@ sub _heap_insert_high {
 
       no strict 'refs'; no warnings 'redefine';
 
+      *{ 'MCE::Queue::clear'      } = \&MCE::Queue::_mce_m_clear;
       *{ 'MCE::Queue::enqueue'    } = \&MCE::Queue::_mce_m_enqueue;
       *{ 'MCE::Queue::enqueuep'   } = \&MCE::Queue::_mce_m_enqueuep;
       *{ 'MCE::Queue::dequeue'    } = \&MCE::Queue::_mce_m_dequeue;
@@ -1030,6 +1017,18 @@ sub _heap_insert_high {
 ##
 ###############################################################################
 
+sub _mce_m_clear {
+
+   my $_next; my $_queue = shift;
+
+   sysread $_queue->{_qr_sock}, $_next, 1
+      if ($_queue->_has_data());
+
+   $_queue->_clear();
+
+   return;
+}
+
 sub _mce_m_enqueue {
 
    my $_queue = shift;
@@ -1163,6 +1162,7 @@ sub _mce_m_insertp {
 
       no strict 'refs'; no warnings 'redefine';
 
+      *{ 'MCE::Queue::clear'      } = \&MCE::Queue::_mce_w_clear;
       *{ 'MCE::Queue::enqueue'    } = \&MCE::Queue::_mce_w_enqueue;
       *{ 'MCE::Queue::enqueuep'   } = \&MCE::Queue::_mce_w_enqueuep;
       *{ 'MCE::Queue::dequeue'    } = \&MCE::Queue::_mce_w_dequeue;
@@ -1180,6 +1180,28 @@ sub _mce_m_insertp {
 
    ## -------------------------------------------------------------------------
 
+   sub _mce_w_clear {
+
+      my $_queue = shift;
+
+      return $_queue->_clear()
+         if (exists $_queue->{_standalone});
+
+      local $\ = undef if (defined $\);
+      local $/ = $LF if (!$/ || $/ ne $LF);
+
+      flock $_DAT_LOCK, LOCK_EX if ($_lock_chn);
+      print $_DAT_W_SOCK OUTPUT_C_QUE . $LF . $_chn . $LF;
+      print $_DAU_W_SOCK $_queue->{_id} . $LF;
+
+      <$_DAU_W_SOCK>;
+      flock $_DAT_LOCK, LOCK_UN if ($_lock_chn);
+
+      return;
+   }
+
+   ## -------------------------------------------------------------------------
+
    sub _mce_w_enqueue {
 
       my $_buffer; my $_queue = shift;
@@ -1566,111 +1588,387 @@ sub _mce_m_insertp {
 
 __END__
 
+###############################################################################
+## ----------------------------------------------------------------------------
+## Module usage.
+##
+###############################################################################
+
 =head1 NAME
 
-MCE::Queue - Provides queues for Many-Core Engine.
+MCE::Queue - Hybrid queues (normal including priority) for Many-core Engine
 
 =head1 VERSION
 
-This document describes MCE::Queue version 1.499_001
+This document describes MCE::Queue version 1.499_002
 
 =head1 SYNOPSIS
 
    use MCE;
    use MCE::Queue;
 
-   my $q = MCE::Queue->new();
+   my @dirs = (".");
 
-   $q->enqueue( $item1 [, $item2, ...] );
-   $q->enqueuep( $p, $item1 [, $item2, ...] );
-   
-   $q->dequeue( [ $count ] );
-   $q->dequeue_nb( [ $count ] );
+   my $D = MCE::Queue->new( queue => \@dirs );
+   my $F = MCE::Queue->new();
 
-   ## TODO ... will finish this prior to the final MCE 1.5 release
+   ## Notice the use of dequeue_nb (non-blocking) for the initial
+   ## task and dequeue for the task afterwards. The first task is
+   ## recursive.
+
+   my $mce = MCE->new(
+
+      user_tasks => [{
+         max_workers => 4,
+
+         task_end => sub {
+
+            ## Signal workers no more work remains. The number 4
+            ## indicates the numbers of workers for the 2nd task
+            ## performing the read.
+
+            $F->enqueue((undef) x 4);
+         },
+
+         user_func => sub {
+
+            ## Pause briefly to allow time for wid 1 to add items.
+            select(undef, undef, undef, 0.05) if (MCE->task_wid > 1);
+
+            ## Worker will loop until no more directories.
+            while (defined (local $_ = $D->dequeue_nb)) {
+               my ($files, $dirs) = part { -d $_ ? 1 : 0 } glob("$_/*");
+
+               $D->enqueue(@$dirs ) if defined $dirs;
+               $F->enqueue(@$files) if defined $files;
+            }
+
+            MCE->say("STDERR", "(D) worker has ended");
+
+            return;
+         }
+
+      },{
+         max_workers => 4,
+
+         user_func => sub {
+
+            ## Worker will loop until no more files.
+            while (defined (local $_ = $F->dequeue)) {
+               MCE->say($_);
+            }
+
+            MCE->say("STDERR", "(F) worker has ended");
+
+            return;
+         }
+      }]
+   );
+
+   $mce->run;
 
 =head1 DESCRIPTION
 
-TODO ... See L<MCE::Flow> for use_case in the meantime.
+This module provides a queue interface supporting normal and priority queues
+and utilizing the IPC engine behind MCE. Queue data resides under the manager
+process. MCE::Queue also allows for a worker to create any number of queues
+locally not available to other workers including the manager processs. Think
+of a CPU having L3 (shared) and L1 (local) cache.
+
+The structure for the MCE::Queue object is provided below. It allows for normal
+queues to run as fast as an array. Data for priority queues are also nearly as
+fast due to having a brief lookup if the priority exists in the hash including
+adding/removal of the key. The heap array contains only priorities, not the
+data itself. This makes the management of the heap order only as neccessary
+while running.
+
+   ## Normal queue data
+   $_queue->{_datq} = [];
+
+   ## Priority data { p1 => [ ], p2 => [ ], pN => [ ] }
+   $_queue->{_datp} = {};
+
+   ## Priority heap [ pN, p2, p1 ] ## in heap order
+   ## fyi, _datp will always dequeue before _datq
+   $_queue->{_heap} = [];
+
+   ## Priority order (default)
+   $_queue->{_porder} = $MCE::Queue::HIGHEST;
+
+   ## Priority type (default)
+   $_queue->{_type} = $MCE::Queue::FIFO;
 
 =head1 IMPORT
 
-One can pass two options to override the default mode used for priority
-queues (has no effect to normal queuing).
+Two options are available for overriding the default value used when creating
+new queues (porder applies to priority queues only).
 
-   porder => $HIGHEST = Highest priority items are dequeued first
-             $LOWEST  = Lowest priority items are dequeued first
+   use MCE::Queue porder => $MCE::Queue::HIGHEST,
+                  type   => $MCE::Queue::FIFO;
 
-   type   => $FIFO    = First in, first out
-             $LILO    =    (Synonym for FIFO)
-             $LIFO    = Last in, first out
-             $FILO    =    (Synonym for LIFO)
+   use MCE::Queue;       ## same as above
 
-   use MCE::Queue porder => $MCE::Queue::HIGHEST, type => $MCE::Queue::FIFO;
+       porder => $HIGHEST = Highest priority items are dequeued first
+                 $LOWEST  = Lowest priority items are dequeued first
 
-   use MCE::Queue;      same as above
+       type   => $FIFO    = First in, first out
+                 $LILO    =    (Synonym for FIFO)
+                 $LIFO    = Last in, first out
+                 $FILO    =    (Synonym for LIFO)
 
-=head1 THREE MODES OF USE
+=head1 THREE RUN MODES
 
-MCE::Queue can be utilized in the following 3 modes:
+MCE::Queue can be utilized under the following conditions:
 
     A) use MCE;           B) use MCE::Queue;    C) use MCE::Queue;
        use MCE::Queue;       use MCE;
 
-A) Loading MCE prior to inclusion of MCE::Queue. The dequeue method blocks
-for the manager process and workers. The manager process contains the data.
-Workers send/request data.
+=over 5
 
-Creating a queue from inside the worker will run the queue in standalone mode.
-Think workers being able to have local queues.
+=item A) Loading MCE prior to inclusion of MCE::Queue
 
-B) Loading MCE::Queue prior to inclusion of MCE. Queues behave as if running
-in standalone mode for both the manager and worker processes for the duration
-of the script.
+The dequeue method blocks for the manager process including workers. All data
+resides under the manager process. Workers send/request data through IPC.
 
-C) Standalone mode without the inclusion of MCE. The dequeue method is
-non-blocking in this mode. This mode is speedy due to minimum overhead.
-In essense, the MCE module is not required to use MCE::Queue.
+Creating a queue from the worker process will cause the queue to run in local
+mode. The data resides under the worker process and not available to other
+workers or even the manager process.
 
-=head1 API
+=item B) Loading MCE::Queue prior to inclusion of MCE
 
-TODO ...
+Queues behave as if running in local mode for the manager including workers
+for the duration of the script. I cannot think of a use-case for this, but
+wanted to mention the behaviour in the event MCE::Queue is loaded prior to
+MCE.
 
-=over
+=item C) Loading MCE::Queue without MCE
 
-=item new
+The dequeue method is non-blocking in this mode. This behaves like local mode
+when MCE is not present. As with local queuing, this mode is speedy due to
+minimum overhead and zero IPC.
 
-=item porder
-
-=item type
-
-=item enqueue
-
-=item enqueuep
-
-=item dequeue
-
-=item dequeue_nb
-
-=item insert
-
-=item insertp
-
-=item pending
-
-=item peek
-
-=item peekh
-
-=item peekp
-
-=item heap
+Basically, the MCE module is not a requirement for using MCE::Queue.
 
 =back
 
-=head1 SEE ALSO
+=head1 API DOCUMENTATION
+
+=over
+
+=item ->new ( [ queue => \@array ] )
+
+This creates a new queue. Available options are queue, porder, type, and
+gather. The gather option is mainly for running with MCE and wanting to pass
+item(s) to a callback function for adding to the queue.
+
+   use MCE;
+   use MCE::Queue;
+
+   my $q1 = MCE::Queue->new();
+   my $q2 = MCE::Queue->new( queue => [ 0, 1, 2 ] );
+
+   my $q3 = MCE::Queue->new( porder => $MCE::Queue::HIGHEST );
+   my $q4 = MCE::Queue->new( porder => $MCE::Queue::LOWEST  );
+
+   my $q5 = MCE::Queue->new( type => $MCE::Queue::FIFO );
+   my $q6 = MCE::Queue->new( type => $MCE::Queue::LIFO );
+
+Multiple queues may point to the same callback funtion. Please note that the
+first argument for the callback function is the queue object itself.
+
+   sub _append {
+      my ($Q, @items) = @_;
+      $Q->enqueue(@items);
+   }
+
+   my $q7 = MCE::Queue->new( gather => \&_append );
+   my $q8 = MCE::Queue->new( gather => \&_append );
+
+   ## Items are diverted to the gather callback function.
+   $q7->enqueue( 'apple', 'orange' );
+
+The gather option is useful when wanting to temporarily store items into a
+holding area until output order can be obtained. Although a queue is not
+required to gather data in MCE, this is simply a demonstation of the
+gather option in the context of a queue.
+
+   use MCE;
+   use MCE::Queue;
+
+   my ($_order_id, %_tmp);
+
+   sub _preserve_order {
+      my ($Q, $chunk_id, $result) = @_;
+
+      $_tmp{$chunk_id} = $result;
+
+      while (1) {
+         last unless exists $_tmp{$_order_id};
+         $Q->enqueue( $_tmp{$_order_id} );
+         delete $_tmp{$_order_id++};
+      }
+
+      return;
+   }
+
+   my @squares; my $q = MCE::Queue->new(
+      queue => \@squares, gather => \&_preserve_order
+   );
+
+   $_order_id = 1;  ## The first chunk_id equals 1;
+
+   my $mce = MCE->new(
+      chunk_size => 1, input_data => [ 1 .. 100 ],
+      user_func => sub {
+         $q->enqueue( MCE->chunk_id, $_ * $_ );
+      }
+   );
+
+   $mce->run;
+
+   print "@squares\n";
+
+=item ->clear ( void )
+
+Clears the queue of any items. This has the effect of nulling the queue.
+Each queue comes with a socket used for blocking behind the scene. Use
+the clear method when wanting to clear the content of the array.
+
+   my @a; my $q = MCE::Queue->new( queue => \@a );
+
+   @a = ();     ## no, the block socket may become out of sync
+   $q->clear;   ## ok
+
+=item ->enqueue ( $item [, $item, ... ] )
+
+Adds a list of items onto the end of the normal queue.
+
+=item ->enqueuep ( $p, $item [, $item, ... ] )
+
+Adds a list of items onto the end of the priority queue with priority.
+
+=item ->dequeue ( [ $count ] )
+
+Returns the requested number of items (default is 1) from the queue. Priority
+data will always dequeue first from the priority queue before any data from
+the normal queue.
+
+The method will block if the queue contains zero items. If the queue contains
+fewer than the requested number of items, the method will not block, but
+return the remaining items and undef for up to the count requested.
+
+The $count, used for requesting the number of times, is beneficial when workers
+are passing arguments through the queue. For this release, always remember to
+dequeue using the same multiple for count. This is unlike Thread::Queue which
+will block until the requested number of items are available.
+
+=item ->dequeue_nb ( [ $count ] )
+
+Returns the requested number of items (default is 1) from the queue. Like with
+dequeue, priority data will always dequeue first. This method is non-blocking
+and will return undef in the absence of data from the queue.
+
+=item ->insert ( $index, $item [, $item, ... ] )
+
+Adds the list of items to the queue at the specified index.
+
+=item ->insertp ( $p, $index, $item [, $item, ... ] )
+
+Adds the list of items to the queue at the specified index with priority.
+
+=item ->pending ( void )
+
+Returns the number of items remaining in the queue. This includes both normal
+and priority data.
+
+=item ->peek ( [ $index ] )
+
+Returns an item from the normal queue, at the specified index, without
+dequeuing anything. It defaults to the head of the queue if index is not
+specified.
+
+=item ->peekp ( $p [, $index ] )
+
+Returns an item from the queue with priority, at the specified index, without
+dequeuing anything. It defaults to the head of the queue if index is not
+specified.
+
+=item ->peekh ( [ $index ] )
+
+Returns an item from the heap, at the specified index.
+
+=item ->heap ( void )
+
+Returns an array containing the heap data. Heap data consists of priority
+numbers, not the data.
+
+=back
+
+=head1 ACKNOWLEDGEMENTS
+
+The main reason for writing MCE::Queue was to have Thread::Queue-like module
+for workers spawned as children with MCE. When searching for queue modules on
+CPAN, I was plesantly surprised at the number of modules out there for Perl.
+What stood out immediately were all the priority queues, heap queues, and
+whether or not FIFO/LIFO or highest/lowest first options were available. It
+seemed like a daunting task to undertake. And so, I began, failed, tried again,
+failed again, and finally on the 3rd attempt was pleased with the results.
+
+The following provides a list of resources I've read in helping me create
+MCE::Queue for MCE.
+
+=over 5
+
+=item L<POE::Queue::Array>
+
+Two if statements were borrowed for checking if the item belongs at the end or
+head of the queue.
+
+=item L<List::Binary::Search>
+
+After glancing over the bsearch_num_pos method for returning the best insert
+position, a couple variations of that were in order for MCE::Queue to
+accomodate the highest/lowest order routines.
+
+The private _heap_insert_low and _heap_insert_high methods inside MCE::Queue
+are simply the 2 if statements and the binary search algorithm.
+
+=item L<Heap-Priority>, L<List::Priority>
+
+At this point, I thought why not have both normal queues and priority queues
+be efficient. And with that in mind, also provide options to allow folks to
+choose LIFO/LILO, and highest/lowest order for the queue. The data structure
+in MCE::Queue is describe above.
+
+MCE workers may also benefit from being able to create local queues not
+available to other workers including the manager process. Thus, the reason
+for the 3 run modes described at the beginning of this document.
+
+=item L<Thread::Queue>
+
+Being that MCE supports both children and threads, Thread::Queue was used as
+a guide for naming and documenting the methods in MCE::Queue. Although not
+100% compatible, pay close attention to the dequeue method in MCE::Queue when
+requesting the number of items to dequeue.
+
+   ->enqueuep( $p, $item [, $item, ... ] );    ## Extension (p)
+   ->enqueue( $item [, $item, ... ] );
+
+   ->dequeue( [ $count ] );      ## Priority data dequeues first
+   ->dequeue_nb( [ $count ] );
+
+   ->pending();                  ## Counts both normal/priority data
+                                 ## in the queue
+
+=item L<Parallel-DataPipe>
+
+The idea for the recusive synopsis used in this document came from reading
+the recursive example seen in this module's documentation.
+
+=back
+
+=head1 INDEX
 
-L<MCE::Flow>, L<MCE::Grep>, L<MCE::Loop>, L<MCE::Map>, L<MCE::Stream>,
 L<MCE>
 
 =head1 AUTHOR
